@@ -11,10 +11,11 @@
   (let ((box (boxfunc homogeneous padding)))
     (for-each (lambda (widget)
 		(if (not (null? widget))
-		    (case (car (cddddr widget))
-		      ((start) (gtk-box-pack-start box (car widget) (cadr widget) (caddr widget) (cadddr widget)))
-		      ((end) (gtk-box-pack-end box (car widget) (cadr widget) (caddr widget) (cadddr widget))))
-		    (gtk-widget-show (car widget))))
+		    (begin
+		      (case (car (cddddr widget))
+			((start) (gtk-box-pack-start box (car widget) (cadr widget) (caddr widget) (cadddr widget)))
+			((end) (gtk-box-pack-end box (car widget) (cadr widget) (caddr widget) (cadddr widget))))
+		      (gtk-widget-show (car widget)))))
 	      widgets)
     (gtk-widget-show box)
     box))
