@@ -7,10 +7,10 @@ void test (char *);
 GtkWidget *main_window;
 GnomePropertyConfigurator *display_config;
 
-void
 load_configurators (void)
 {
 	background_setup (main_window);
+        screensaver_setup (main_window);
 }
 
 void
@@ -55,14 +55,23 @@ get_monitor_preview_widget (GtkWidget *window)
 	return pwid;
 }
 
+static destroy (GtkWidget *widget, gpointer *data)
+{
+	gtk_main_quit ();
+}
+
 void
 display_properties_setup (void)
 {
-	main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_widget_show (main_window);
 	display_config = gnome_property_configurator_new ();
+	main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_signal_connect (GTK_OBJECT (main_window), "destroy",
+			    GTK_SIGNAL_FUNC (destroy), NULL);
+
 	gtk_container_add (GTK_CONTAINER(main_window), display_config->notebook);
+	configurators_setup ();
 	gtk_widget_show (display_config->notebook);
+	gtk_widget_show (main_window);
 }
 
 int
@@ -72,7 +81,6 @@ main (int argc, char *argv [])
 	gnome_init (&argc, &argv);
 	
 	display_properties_setup ();
-	configurators_setup ();
 #if 0
 	{
 		GtkWidget *window;
@@ -113,4 +121,3 @@ test (char *msg)
 	
 	register_extension (label, frame, NULL);
 }
-
