@@ -24,8 +24,8 @@
 		       (gtk-text-insert text-widget #f #f #f
 					(string the-char) 1)
 		       (if (eq? the-char #\newline)
-			   (gtk-text-thaw text-widget))
-			   
+			     (gtk-text-thaw text-widget))
+		       
 		       (if (not (eof-object? pipe))
 			   (if (char-ready? pipe)
 			       (try-another-char))))))))))
@@ -47,8 +47,12 @@
 					(gnome-boxed-widget details #f #f 0 'end))
 				       #f #f 0 'start)
 		   (gnome-boxed-widget extended-options-widget #f #f 4 'start)))
-	 (text    (gtk-text-new (gtk-adjustment-new 0.0 0.0 0.0 0.0 0.0 0.0)
-				(gtk-adjustment-new 0.0 0.0 0.0 0.0 0.0 0.0)))
+	 (hadj    (gtk-adjustment-new 0.0 0.0 0.0 0.0 0.0 0.0))
+	 (vadj    (gtk-adjustment-new 0.0 0.0 0.0 0.0 0.0 0.0))
+	 (table   (gtk-table-new 2 2 #f))
+	 (hsbar   (gtk-hscrollbar-new hadj))
+	 (vsbar   (gtk-vscrollbar-new vadj))
+	 (text    (gtk-text-new hadj vadj))
 	 (panel   (gnome-make-filled-vbox
 		   #f 4
 		   
@@ -68,7 +72,12 @@
 		   
 		   ; Output text widget
 		   
-		   (gnome-boxed-widget text #t #t 0 'end))))
+		   (gnome-boxed-widget table #t #t 0 'end))))
+
+    (gtk-table-attach table text 0 1 0 1 '(expand fill) '(expand fill) 0 0)
+    (gtk-table-attach table hsbar 0 1 1 2 '(expand fill) '() 0 0)
+    (gtk-table-attach table vsbar 1 2 0 1 '() '(expand fill) 0 0)
+    (gtk-widget-show-multi text hsbar vsbar)
 
     ; HACK HACK HACK: GtkText should be fixed (recompute_geometry(),
     ; gtk_text_realize(), gtk_text_size_allocate())
@@ -366,7 +375,7 @@
       #f
       3
       (gnome-boxed-widget (gtk-label-new "GNOME Network Utilities") #f #f 0 'start)
-      (gnome-boxed-widget (gtk-label-new "Version 0.0.d10") #f #f  0 'start)
+      (gnome-boxed-widget (gtk-label-new "Version @MYVERSION@") #f #f  0 'start)
       (gnome-boxed-widget (gtk-label-new "Federico Mena <federico@nuclecu.unam.mx>") #f #f 0 'start)
       (gnome-boxed-widget (gtk-label-new "Miguel de Icaza <miguel@nuclecu.unam.mx>") #f #f 0 'start)))
     (gtk-widget-show alignment)
@@ -388,7 +397,7 @@
 	(hbox (gtk-hbox-new #f 0))
 	(quit (gtk-button-new-with-label "    Quit    ")))
     (gtk-window-set-title window "GNOME Network Utilities")
-    (gtk-signal-connect window "destroy" (lambda () (gtk-main-quit)))
+    (gtk-signal-connect window "delete_event" (lambda (x) (gtk-main-quit) 1))
     (gtk-container-add window vbox)
     (gtk-box-pack-start vbox (create-itools-notebook) #f #f 0)
     (gtk-container-border-width hbox 4)
